@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -38,6 +43,7 @@
 
 #include "window.h"
 
+//! [0]
 Window::Window(QWidget *parent)
     : QDialog(parent)
 {
@@ -54,7 +60,9 @@ Window::Window(QWidget *parent)
     filesFoundLabel = new QLabel;
 
     createFilesTable();
+//! [0]
 
+//! [1]
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
     buttonsLayout->addStretch();
     buttonsLayout->addWidget(findButton);
@@ -75,17 +83,29 @@ Window::Window(QWidget *parent)
     setWindowTitle(tr("Find Files"));
     resize(700, 300);
 }
+//! [1]
 
+//! [2]
 void Window::browse()
 {
     QString directory = QFileDialog::getExistingDirectory(this,
                                tr("Find Files"), QDir::currentPath());
+
     if (!directory.isEmpty()) {
-        directoryComboBox->addItem(directory);
-        directoryComboBox->setCurrentIndex(directoryComboBox->currentIndex() + 1);
+        if (directoryComboBox->findText(directory) == -1)
+            directoryComboBox->addItem(directory);
+        directoryComboBox->setCurrentIndex(directoryComboBox->findText(directory));
     }
 }
+//! [2]
 
+static void updateComboBox(QComboBox *comboBox)
+{
+    if (comboBox->findText(comboBox->currentText()) == -1)
+        comboBox->addItem(comboBox->currentText());
+}
+
+//! [3]
 void Window::find()
 {
     filesTable->setRowCount(0);
@@ -93,27 +113,35 @@ void Window::find()
     QString fileName = fileComboBox->currentText();
     QString text = textComboBox->currentText();
     QString path = directoryComboBox->currentText();
+//! [3]
 
-    QDir directory = QDir(path);
+    updateComboBox(fileComboBox);
+    updateComboBox(textComboBox);
+    updateComboBox(directoryComboBox);
+
+//! [4]
+    currentDir = QDir(path);
     QStringList files;
     if (fileName.isEmpty())
         fileName = "*";
-    files = directory.entryList(QStringList(fileName),
-                                QDir::Files | QDir::NoSymLinks);
+    files = currentDir.entryList(QStringList(fileName),
+                                 QDir::Files | QDir::NoSymLinks);
 
     if (!text.isEmpty())
-        files = findFiles(directory, files, text);
-    showFiles(directory, files);
+        files = findFiles(files, text);
+    showFiles(files);
 }
+//! [4]
 
-QStringList Window::findFiles(const QDir &directory, const QStringList &files,
-                              const QString &text)
+//! [5]
+QStringList Window::findFiles(const QStringList &files, const QString &text)
 {
     QProgressDialog progressDialog(this);
     progressDialog.setCancelButtonText(tr("&Cancel"));
     progressDialog.setRange(0, files.size());
     progressDialog.setWindowTitle(tr("Find Files"));
 
+//! [5] //! [6]
     QStringList foundFiles;
 
     for (int i = 0; i < files.size(); ++i) {
@@ -121,11 +149,13 @@ QStringList Window::findFiles(const QDir &directory, const QStringList &files,
         progressDialog.setLabelText(tr("Searching file number %1 of %2...")
                                     .arg(i).arg(files.size()));
         qApp->processEvents();
+//! [6]
 
         if (progressDialog.wasCanceled())
             break;
 
-        QFile file(directory.absoluteFilePath(files[i]));
+//! [7]
+        QFile file(currentDir.absoluteFilePath(files[i]));
 
         if (file.open(QIODevice::ReadOnly)) {
             QString line;
@@ -143,35 +173,42 @@ QStringList Window::findFiles(const QDir &directory, const QStringList &files,
     }
     return foundFiles;
 }
+//! [7]
 
-void Window::showFiles(const QDir &directory, const QStringList &files)
+//! [8]
+void Window::showFiles(const QStringList &files)
 {
     for (int i = 0; i < files.size(); ++i) {
-        QFile file(directory.absoluteFilePath(files[i]));
+        QFile file(currentDir.absoluteFilePath(files[i]));
         qint64 size = QFileInfo(file).size();
 
         QTableWidgetItem *fileNameItem = new QTableWidgetItem(files[i]);
-        fileNameItem->setFlags(Qt::ItemIsEnabled);
+        fileNameItem->setFlags(fileNameItem->flags() ^ Qt::ItemIsEditable);
         QTableWidgetItem *sizeItem = new QTableWidgetItem(tr("%1 KB")
                                              .arg(int((size + 1023) / 1024)));
         sizeItem->setTextAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        sizeItem->setFlags(Qt::ItemIsEnabled);
+        sizeItem->setFlags(sizeItem->flags() ^ Qt::ItemIsEditable);
 
         int row = filesTable->rowCount();
         filesTable->insertRow(row);
         filesTable->setItem(row, 0, fileNameItem);
         filesTable->setItem(row, 1, sizeItem);
     }
-    filesFoundLabel->setText(tr("%1 file(s) found").arg(files.size()));
+    filesFoundLabel->setText(tr("%1 file(s) found").arg(files.size()) +
+                             (" (Double click on a file to open it)"));
 }
+//! [8]
 
+//! [9]
 QPushButton *Window::createButton(const QString &text, const char *member)
 {
     QPushButton *button = new QPushButton(text);
     connect(button, SIGNAL(clicked()), this, member);
     return button;
 }
+//! [9]
 
+//! [10]
 QComboBox *Window::createComboBox(const QString &text)
 {
     QComboBox *comboBox = new QComboBox;
@@ -180,14 +217,34 @@ QComboBox *Window::createComboBox(const QString &text)
     comboBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
     return comboBox;
 }
+//! [10]
 
+//! [11]
 void Window::createFilesTable()
 {
     filesTable = new QTableWidget(0, 2);
+    filesTable->setSelectionBehavior(QAbstractItemView::SelectRows);
+
     QStringList labels;
     labels << tr("File Name") << tr("Size");
     filesTable->setHorizontalHeaderLabels(labels);
     filesTable->horizontalHeader()->setResizeMode(0, QHeaderView::Stretch);
     filesTable->verticalHeader()->hide();
     filesTable->setShowGrid(false);
+
+    connect(filesTable, SIGNAL(cellActivated(int, int)),
+            this, SLOT(openFileOfItem(int, int)));
 }
+//! [11]
+
+//! [12]
+
+void Window::openFileOfItem(int row, int /* column */)
+{
+    QTableWidgetItem *item = filesTable->item(row, 0);
+
+    QDesktopServices::openUrl(currentDir.absoluteFilePath(item->text()));
+}
+
+//! [12]
+
