@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -39,25 +44,34 @@
 
 #include <QWizard>
 
+QT_BEGIN_NAMESPACE
 class QCheckBox;
 class QLabel;
 class QLineEdit;
 class QRadioButton;
+QT_END_NAMESPACE
 
+//! [0] //! [1]
 class LicenseWizard : public QWizard
 {
+//! [0]
     Q_OBJECT
 
 public:
+//! [2]
     enum { Page_Intro, Page_Evaluate, Page_Register, Page_Details,
            Page_Conclusion };
+//! [2]
 
     LicenseWizard(QWidget *parent = 0);
 
 private slots:
     void showHelp();
+//! [3]
 };
+//! [1] //! [3]
 
+//! [4]
 class IntroPage : public QWizardPage
 {
     Q_OBJECT
@@ -72,7 +86,9 @@ private:
     QRadioButton *registerRadioButton;
     QRadioButton *evaluateRadioButton;
 };
+//! [4]
 
+//! [5]
 class EvaluatePage : public QWizardPage
 {
     Q_OBJECT
@@ -88,6 +104,7 @@ private:
     QLineEdit *nameLineEdit;
     QLineEdit *emailLineEdit;
 };
+//! [5]
 
 class RegisterPage : public QWizardPage
 {
@@ -123,6 +140,7 @@ private:
     QLineEdit *postalLineEdit;
 };
 
+//! [6]
 class ConclusionPage : public QWizardPage
 {
     Q_OBJECT
@@ -141,5 +159,6 @@ private:
     QLabel *bottomLabel;
     QCheckBox *agreeCheckBox;
 };
+//! [6]
 
 #endif
