@@ -1,38 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -105,23 +108,30 @@ QSize FtpWindow::sizeHint() const
     return QSize(500, 300);
 }
 
+//![0]
 void FtpWindow::connectOrDisconnect()
 {
     if (ftp) {
         ftp->abort();
         ftp->deleteLater();
         ftp = 0;
+//![0]
         fileList->setEnabled(false);
         cdToParentButton->setEnabled(false);
         downloadButton->setEnabled(false);
         connectButton->setEnabled(true);
         connectButton->setText(tr("Connect"));
+#ifndef QT_NO_CURSOR
         setCursor(Qt::ArrowCursor);
+#endif
         return;
     }
 
+#ifndef QT_NO_CURSOR
     setCursor(Qt::WaitCursor);
-    
+#endif
+
+//![1]    
     ftp = new QFtp(this);
     connect(ftp, SIGNAL(commandFinished(int, bool)),
             this, SLOT(ftpCommandFinished(int, bool)));
@@ -133,7 +143,9 @@ void FtpWindow::connectOrDisconnect()
     fileList->clear();
     currentPath.clear();
     isDirectory.clear();
+//![1]
 
+//![2]
     QUrl url(ftpServerLineEdit->text());
     if (!url.isValid() || url.scheme().toLower() != QLatin1String("ftp")) {
         ftp->connectToHost(ftpServerLineEdit->text(), 21);
@@ -148,6 +160,7 @@ void FtpWindow::connectOrDisconnect()
         if (!url.path().isEmpty())
             ftp->cd(url.path());
     }
+//![2]
 
     fileList->setEnabled(true);
     connectButton->setEnabled(false);
@@ -156,10 +169,12 @@ void FtpWindow::connectOrDisconnect()
                          .arg(ftpServerLineEdit->text()));
 }
 
+//![3]
 void FtpWindow::downloadFile()
 {
     QString fileName = fileList->currentItem()->text(0);
-
+//![3]
+//
     if (QFile::exists(fileName)) {
         QMessageBox::information(this, tr("FTP"),
                                  tr("There already exists a file called %1 in "
@@ -168,6 +183,7 @@ void FtpWindow::downloadFile()
         return;
     }
 
+//![4]
     file = new QFile(fileName);
     if (!file->open(QIODevice::WriteOnly)) {
         QMessageBox::information(this, tr("FTP"),
@@ -183,15 +199,21 @@ void FtpWindow::downloadFile()
     downloadButton->setEnabled(false);
     progressDialog->exec();
 }
+//![4]
 
+//![5]
 void FtpWindow::cancelDownload()
 {
     ftp->abort();
 }
+//![5]
 
+//![6]
 void FtpWindow::ftpCommandFinished(int, bool error)
 {
+#ifndef QT_NO_CURSOR
     setCursor(Qt::ArrowCursor);
+#endif
 
     if (ftp->currentCommand() == QFtp::ConnectToHost) {
         if (error) {
@@ -203,7 +225,6 @@ void FtpWindow::ftpCommandFinished(int, bool error)
             connectOrDisconnect();
             return;
         }
-
         statusLabel->setText(tr("Logged onto %1.")
                              .arg(ftpServerLineEdit->text()));
         fileList->setFocus();
@@ -211,10 +232,14 @@ void FtpWindow::ftpCommandFinished(int, bool error)
         connectButton->setEnabled(true);
         return;
     }
+//![6]
 
+//![7]
     if (ftp->currentCommand() == QFtp::Login)
         ftp->list();
+//![7]
 
+//![8]
     if (ftp->currentCommand() == QFtp::Get) {
         if (error) {
             statusLabel->setText(tr("Canceled download of %1.")
@@ -229,14 +254,18 @@ void FtpWindow::ftpCommandFinished(int, bool error)
         delete file;
         enableDownloadButton();
         progressDialog->hide();
+//![8]
+//![9]
     } else if (ftp->currentCommand() == QFtp::List) {
         if (isDirectory.isEmpty()) {
             fileList->addTopLevelItem(new QTreeWidgetItem(QStringList() << tr("<empty>")));
             fileList->setEnabled(false);
         }
     }
+//![9]
 }
 
+//![10]
 void FtpWindow::addToList(const QUrlInfo &urlInfo)
 {
     QTreeWidgetItem *item = new QTreeWidgetItem;
@@ -256,7 +285,9 @@ void FtpWindow::addToList(const QUrlInfo &urlInfo)
         fileList->setEnabled(true);
     }
 }
+//![10]
 
+//![11]
 void FtpWindow::processItem(QTreeWidgetItem *item, int /*column*/)
 {
     QString name = item->text(0);
@@ -267,14 +298,20 @@ void FtpWindow::processItem(QTreeWidgetItem *item, int /*column*/)
         ftp->cd(name);
         ftp->list();
         cdToParentButton->setEnabled(true);
+#ifndef QT_NO_CURSOR
         setCursor(Qt::WaitCursor);
+#endif
         return;
     }
 }
+//![11]
 
+//![12]
 void FtpWindow::cdToParent()
 {
+#ifndef QT_NO_CURSOR
     setCursor(Qt::WaitCursor);
+#endif
     fileList->clear();
     isDirectory.clear();
     currentPath = currentPath.left(currentPath.lastIndexOf('/'));
@@ -286,14 +323,18 @@ void FtpWindow::cdToParent()
     }
     ftp->list();
 }
+//![12]
 
+//![13]
 void FtpWindow::updateDataTransferProgress(qint64 readBytes,
                                            qint64 totalBytes)
 {
     progressDialog->setMaximum(totalBytes);
     progressDialog->setValue(readBytes);
 }
+//![13]
 
+//![14]
 void FtpWindow::enableDownloadButton()
 {
     QTreeWidgetItem *current = fileList->currentItem();
@@ -304,3 +345,5 @@ void FtpWindow::enableDownloadButton()
         downloadButton->setEnabled(false);
     }
 }
+//![14]
+
