@@ -1,38 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-** 
-** Trolltech ASA (c) 2007
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -41,8 +44,11 @@
 #include "renderarea.h"
 #include "window.h"
 
+//! [0]
 const int IdRole = Qt::UserRole;
+//! [0]
 
+//! [1]
 Window::Window()
 {
     renderArea = new RenderArea;
@@ -50,7 +56,7 @@ Window::Window()
     shapeComboBox = new QComboBox;
     shapeComboBox->addItem(tr("Polygon"), RenderArea::Polygon);
     shapeComboBox->addItem(tr("Rectangle"), RenderArea::Rect);
-    shapeComboBox->addItem(tr("Round Rectangle"), RenderArea::RoundRect);
+    shapeComboBox->addItem(tr("Rounded Rectangle"), RenderArea::RoundedRect);
     shapeComboBox->addItem(tr("Ellipse"), RenderArea::Ellipse);
     shapeComboBox->addItem(tr("Pie"), RenderArea::Pie);
     shapeComboBox->addItem(tr("Chord"), RenderArea::Chord);
@@ -64,14 +70,18 @@ Window::Window()
 
     shapeLabel = new QLabel(tr("&Shape:"));
     shapeLabel->setBuddy(shapeComboBox);
+//! [1]
 
+//! [2]
     penWidthSpinBox = new QSpinBox;
     penWidthSpinBox->setRange(0, 20);
     penWidthSpinBox->setSpecialValueText(tr("0 (cosmetic pen)"));
 
     penWidthLabel = new QLabel(tr("Pen &Width:"));
     penWidthLabel->setBuddy(penWidthSpinBox);
+//! [2]
 
+//! [3]
     penStyleComboBox = new QComboBox;
     penStyleComboBox->addItem(tr("Solid"), Qt::SolidLine);
     penStyleComboBox->addItem(tr("Dash"), Qt::DashLine);
@@ -98,7 +108,9 @@ Window::Window()
 
     penJoinLabel = new QLabel(tr("Pen &Join:"));
     penJoinLabel->setBuddy(penJoinComboBox);
+//! [3]
 
+//! [4]
     brushStyleComboBox = new QComboBox;
     brushStyleComboBox->addItem(tr("Linear Gradient"),
             Qt::LinearGradientPattern);
@@ -125,11 +137,17 @@ Window::Window()
 
     brushStyleLabel = new QLabel(tr("&Brush Style:"));
     brushStyleLabel->setBuddy(brushStyleComboBox);
+//! [4]
 
+//! [5]
     otherOptionsLabel = new QLabel(tr("Other Options:"));
+//! [5] //! [6]
     antialiasingCheckBox = new QCheckBox(tr("&Antialiasing"));
+//! [6] //! [7]
     transformationsCheckBox = new QCheckBox(tr("&Transformations"));
+//! [7]
 
+//! [8]
     connect(shapeComboBox, SIGNAL(activated(int)),
             this, SLOT(shapeChanged()));
     connect(penWidthSpinBox, SIGNAL(valueChanged(int)),
@@ -146,8 +164,11 @@ Window::Window()
             renderArea, SLOT(setAntialiased(bool)));
     connect(transformationsCheckBox, SIGNAL(toggled(bool)),
             renderArea, SLOT(setTransformed(bool)));
+//! [8]
 
+//! [9]
     QGridLayout *mainLayout = new QGridLayout;
+//! [9] //! [10]
     mainLayout->setColumnStretch(0, 1);
     mainLayout->setColumnStretch(3, 1);
     mainLayout->addWidget(renderArea, 0, 0, 1, 4);
@@ -177,14 +198,18 @@ Window::Window()
 
     setWindowTitle(tr("Basic Drawing"));
 }
+//! [10]
 
+//! [11]
 void Window::shapeChanged()
 {
     RenderArea::Shape shape = RenderArea::Shape(shapeComboBox->itemData(
             shapeComboBox->currentIndex(), IdRole).toInt());
     renderArea->setShape(shape);
 }
+//! [11]
 
+//! [12]
 void Window::penChanged()
 {
     int width = penWidthSpinBox->value();
@@ -197,18 +222,23 @@ void Window::penChanged()
 
     renderArea->setPen(QPen(Qt::blue, width, style, cap, join));
 }
+//! [12]
 
+//! [13]
 void Window::brushChanged()
 {
     Qt::BrushStyle style = Qt::BrushStyle(brushStyleComboBox->itemData(
+//! [13]
             brushStyleComboBox->currentIndex(), IdRole).toInt());
 
+//! [14]
     if (style == Qt::LinearGradientPattern) {
         QLinearGradient linearGradient(0, 0, 100, 100);
         linearGradient.setColorAt(0.0, Qt::white);
         linearGradient.setColorAt(0.2, Qt::green);
         linearGradient.setColorAt(1.0, Qt::black);
         renderArea->setBrush(linearGradient);
+//! [14] //! [15]
     } else if (style == Qt::RadialGradientPattern) {
         QRadialGradient radialGradient(50, 50, 50, 70, 70);
         radialGradient.setColorAt(0.0, Qt::white);
@@ -221,9 +251,12 @@ void Window::brushChanged()
         conicalGradient.setColorAt(0.2, Qt::green);
         conicalGradient.setColorAt(1.0, Qt::black);
         renderArea->setBrush(conicalGradient);
+//! [15] //! [16]
     } else if (style == Qt::TexturePattern) {
         renderArea->setBrush(QBrush(QPixmap(":/images/brick.png")));
+//! [16] //! [17]
     } else {
         renderArea->setBrush(QBrush(Qt::green, style));
     }
 }
+//! [17]
