@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -47,6 +45,7 @@
 
 #include "mandelbrotwidget.h"
 
+//! [0]
 const double DefaultCenterX = -0.637011f;
 const double DefaultCenterY = -0.0395159f;
 const double DefaultScale = 0.00403897f;
@@ -54,7 +53,9 @@ const double DefaultScale = 0.00403897f;
 const double ZoomInFactor = 0.8f;
 const double ZoomOutFactor = 1 / ZoomInFactor;
 const int ScrollStep = 20;
+//! [0]
 
+//! [1]
 MandelbrotWidget::MandelbrotWidget(QWidget *parent)
     : QWidget(parent)
 {
@@ -68,10 +69,14 @@ MandelbrotWidget::MandelbrotWidget(QWidget *parent)
             this, SLOT(updatePixmap(const QImage &, double)));
 
     setWindowTitle(tr("Mandelbrot"));
+#ifndef QT_NO_CURSOR
     setCursor(Qt::CrossCursor);
+#endif
     resize(550, 400);
 }
+//! [1]
 
+//! [2]
 void MandelbrotWidget::paintEvent(QPaintEvent * /* event */)
 {
     QPainter painter(this);
@@ -81,12 +86,19 @@ void MandelbrotWidget::paintEvent(QPaintEvent * /* event */)
         painter.setPen(Qt::white);
         painter.drawText(rect(), Qt::AlignCenter,
                          tr("Rendering initial image, please wait..."));
+//! [2] //! [3]
         return;
+//! [3] //! [4]
     }
+//! [4]
 
+//! [5]
     if (curScale == pixmapScale) {
+//! [5] //! [6]
         painter.drawPixmap(pixmapOffset, pixmap);
+//! [6] //! [7]
     } else {
+//! [7] //! [8]
         double scaleFactor = pixmapScale / curScale;
         int newWidth = int(pixmap.width() * scaleFactor);
         int newHeight = int(pixmap.height() * scaleFactor);
@@ -100,6 +112,7 @@ void MandelbrotWidget::paintEvent(QPaintEvent * /* event */)
         painter.drawPixmap(exposed, pixmap, exposed);
         painter.restore();
     }
+//! [8] //! [9]
 
     QString text = tr("Use mouse wheel or the '+' and '-' keys to zoom. "
                       "Press and hold left mouse button to scroll.");
@@ -114,12 +127,16 @@ void MandelbrotWidget::paintEvent(QPaintEvent * /* event */)
     painter.drawText((width() - textWidth) / 2,
                      metrics.leading() + metrics.ascent(), text);
 }
+//! [9]
 
+//! [10]
 void MandelbrotWidget::resizeEvent(QResizeEvent * /* event */)
 {
     thread.render(centerX, centerY, curScale, size());
 }
+//! [10]
 
+//! [11]
 void MandelbrotWidget::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
@@ -145,20 +162,26 @@ void MandelbrotWidget::keyPressEvent(QKeyEvent *event)
         QWidget::keyPressEvent(event);
     }
 }
+//! [11]
 
+//! [12]
 void MandelbrotWidget::wheelEvent(QWheelEvent *event)
 {
     int numDegrees = event->delta() / 8;
     double numSteps = numDegrees / 15.0f;
     zoom(pow(ZoomInFactor, numSteps));
 }
+//! [12]
 
+//! [13]
 void MandelbrotWidget::mousePressEvent(QMouseEvent *event)
 {
     if (event->button() == Qt::LeftButton)
         lastDragPos = event->pos();
 }
+//! [13]
 
+//! [14]
 void MandelbrotWidget::mouseMoveEvent(QMouseEvent *event)
 {
     if (event->buttons() & Qt::LeftButton) {
@@ -167,7 +190,9 @@ void MandelbrotWidget::mouseMoveEvent(QMouseEvent *event)
         update();
     }
 }
+//! [14]
 
+//! [15]
 void MandelbrotWidget::mouseReleaseEvent(QMouseEvent *event)
 {
     if (event->button() == Qt::LeftButton) {
@@ -179,7 +204,9 @@ void MandelbrotWidget::mouseReleaseEvent(QMouseEvent *event)
         scroll(deltaX, deltaY);
     }
 }
+//! [15]
 
+//! [16]
 void MandelbrotWidget::updatePixmap(const QImage &image, double scaleFactor)
 {
     if (!lastDragPos.isNull())
@@ -191,14 +218,18 @@ void MandelbrotWidget::updatePixmap(const QImage &image, double scaleFactor)
     pixmapScale = scaleFactor;
     update();
 }
+//! [16]
 
+//! [17]
 void MandelbrotWidget::zoom(double zoomFactor)
 {
     curScale *= zoomFactor;
     update();
     thread.render(centerX, centerY, curScale, size());
 }
+//! [17]
 
+//! [18]
 void MandelbrotWidget::scroll(int deltaX, int deltaY)
 {
     centerX += deltaX * curScale;
@@ -206,3 +237,4 @@ void MandelbrotWidget::scroll(int deltaX, int deltaY)
     update();
     thread.render(centerX, centerY, curScale, size());
 }
+//! [18]
