@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -45,6 +43,7 @@
 #include "dirmodel.h"
 #include "mainwindow.h"
 
+//! [0]
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), completer(0), lineEdit(0)
 {
@@ -76,18 +75,24 @@ MainWindow::MainWindow(QWidget *parent)
     caseCombo->addItem(tr("Case Insensitive"));
     caseCombo->addItem(tr("Case Sensitive"));
     caseCombo->setCurrentIndex(0);
+//! [0]
 
+//! [1]
     wrapCheckBox = new QCheckBox;
     wrapCheckBox->setText(tr("Wrap around completions"));
     wrapCheckBox->setChecked(true);
+//! [1]
 
+//! [2]
     contentsLabel = new QLabel;
     contentsLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
     connect(modelCombo, SIGNAL(activated(int)), this, SLOT(changeModel()));
     connect(modeCombo, SIGNAL(activated(int)), this, SLOT(changeMode(int)));
     connect(caseCombo, SIGNAL(activated(int)), this, SLOT(changeCase(int)));
+//! [2]
 
+//! [3]
     lineEdit = new QLineEdit;
     
     QGridLayout *layout = new QGridLayout;
@@ -105,7 +110,9 @@ MainWindow::MainWindow(QWidget *parent)
     setWindowTitle(tr("Completer"));
     lineEdit->setFocus();
 }
+//! [3]
 
+//! [4]
 void MainWindow::createMenu()
 {
     QAction *exitAction = new QAction(tr("Exit"), this);
@@ -123,14 +130,20 @@ void MainWindow::createMenu()
     helpMenu->addAction(aboutAct);
     helpMenu->addAction(aboutQtAct);
 }
+//! [4]
 
+//! [5]
 QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
 {
     QFile file(fileName);
     if (!file.open(QFile::ReadOnly))
         return new QStringListModel(completer);
+//! [5]
 
+//! [6]
+#ifndef QT_NO_CURSOR
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+#endif
     QStringList words;
 
     while (!file.atEnd()) {
@@ -139,14 +152,21 @@ QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
             words << line.trimmed();
     }
 
+#ifndef QT_NO_CURSOR
     QApplication::restoreOverrideCursor();
+#endif
+//! [6]
 
+//! [7]
     if (!fileName.contains(QLatin1String("countries.txt")))
         return new QStringListModel(words, completer);
+//! [7]
 
     // The last two chars of the countries.txt file indicate the country
     // symbol. We put that in column 2 of a standard item model
+//! [8]
     QStandardItemModel *m = new QStandardItemModel(words.count(), 2, completer);
+//! [8] //! [9]
     for (int i = 0; i < words.count(); ++i) {
         QModelIndex countryIdx = m->index(i, 0);
         QModelIndex symbolIdx = m->index(i, 1);
@@ -158,7 +178,9 @@ QAbstractItemModel *MainWindow::modelFromFile(const QString& fileName)
 
     return m;
 }
+//! [9]
 
+//! [10]
 void MainWindow::changeMode(int index)
 {
     QCompleter::CompletionMode mode;
@@ -171,12 +193,14 @@ void MainWindow::changeMode(int index)
 
     completer->setCompletionMode(mode);
 }
+//! [10]
 
 void MainWindow::changeCase(int cs)
 {
     completer->setCaseSensitivity(cs ? Qt::CaseSensitive : Qt::CaseInsensitive);
 }
 
+//! [11]
 void MainWindow::changeModel()
 {
     delete completer;
@@ -191,6 +215,7 @@ void MainWindow::changeModel()
             contentsLabel->setText(tr("Enter file path"));
         }
         break;
+//! [11] //! [12]
     case 1:
         { // DirModel that shows full paths
             DirModel *dirModel = new DirModel(completer);
@@ -198,6 +223,7 @@ void MainWindow::changeModel()
             contentsLabel->setText(tr("Enter file path"));
         }
         break;
+//! [12] //! [13]
     case 2:
         { // Country List
             completer->setModel(modelFromFile(":/resources/countries.txt"));
@@ -211,6 +237,7 @@ void MainWindow::changeModel()
             contentsLabel->setText(tr("Enter name of your country"));
         }
         break;
+//! [13] //! [14]
     case 3:
         { // Word list
             completer->setModel(modelFromFile(":/resources/wordlist.txt"));
@@ -226,9 +253,12 @@ void MainWindow::changeModel()
     lineEdit->setCompleter(completer);
     connect(wrapCheckBox, SIGNAL(clicked(bool)), completer, SLOT(setWrapAround(bool)));
 }
+//! [14]
 
+//! [15]
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About"), tr("This example demonstrates the "
         "different features of the QCompleter class."));
 }
+//! [15]
