@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -39,13 +44,13 @@
 
 #include "tabletcanvas.h"
 
+//! [0]
 TabletCanvas::TabletCanvas()
 {
+    resize(500, 500);
     myBrush = QBrush();
     myPen = QPen();
-    image = QImage(500, 500, QImage::Format_ARGB32);
-    QPainter painter(&image);
-    painter.fillRect(0, 0, 499, 499, Qt::white);
+    initImage();
     setAutoFillBackground(true);
     deviceDown = false;
     myColor = Qt::red;
@@ -55,11 +60,26 @@ TabletCanvas::TabletCanvas()
     lineWidthType = LineWidthPressure;
 }
 
+void TabletCanvas::initImage()
+{
+    QImage newImage = QImage(width(), height(), QImage::Format_ARGB32);
+    QPainter painter(&newImage);
+    painter.fillRect(0, 0, newImage.width(), newImage.height(), Qt::white);
+    if (!image.isNull())
+        painter.drawImage(0, 0, image);
+    painter.end();
+    image = newImage;
+}
+//! [0]
+
+//! [1]
 bool TabletCanvas::saveImage(const QString &file)
 {
     return image.save(file);
 }
+//! [1]
 
+//! [2]
 bool TabletCanvas::loadImage(const QString &file)
 {
     bool success = image.load(file);
@@ -70,7 +90,9 @@ bool TabletCanvas::loadImage(const QString &file)
     }
     return false;
 }
+//! [2]
 
+//! [3]
 void TabletCanvas::tabletEvent(QTabletEvent *event)
 {
 
@@ -99,13 +121,17 @@ void TabletCanvas::tabletEvent(QTabletEvent *event)
     }
     update();
 }
+//! [3]
 
+//! [4]
 void TabletCanvas::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
     painter.drawImage(QPoint(0, 0), image);
 }
+//! [4]
 
+//! [5]
 void TabletCanvas::paintImage(QPainter &painter, QTabletEvent *event)
 {
     QPoint brushAdjust(10, 10);
@@ -127,11 +153,18 @@ void TabletCanvas::paintImage(QPainter &painter, QTabletEvent *event)
                                     polyLine[i] + brushAdjust));
             }
             break;
+        case QTabletEvent::Puck:
+        case QTabletEvent::FourDMouse:
+        case QTabletEvent::RotationStylus:
+            qWarning("This input device is not supported by the example.");
+            break;
         default:
-            qWarning("Unsupported tablet device.");
+            qWarning("Unknown tablet device.");
     }
 }
+//! [5]
 
+//! [6]
 Qt::BrushStyle TabletCanvas::brushPattern(qreal value)
 {
     int pattern = int((value) * 100.0) % 7;
@@ -155,7 +188,9 @@ Qt::BrushStyle TabletCanvas::brushPattern(qreal value)
             return Qt::Dense7Pattern;
     }
 }
+//! [6]
 
+//! [7]
 void TabletCanvas::updateBrush(QTabletEvent *event)
 {
     int hue, saturation, value, alpha;
@@ -163,18 +198,20 @@ void TabletCanvas::updateBrush(QTabletEvent *event)
 
     int vValue = int(((event->yTilt() + 60.0) / 120.0) * 255);
     int hValue = int(((event->xTilt() + 60.0) / 120.0) * 255);
+//! [7] //! [8]
 
     switch (alphaChannelType) {
         case AlphaPressure:
             myColor.setAlpha(int(event->pressure() * 255.0));
             break;
         case AlphaTilt:
-            myColor.setAlpha(max(abs(vValue - 127), abs(hValue - 127)));
+            myColor.setAlpha(maximum(abs(vValue - 127), abs(hValue - 127)));
             break;
         default:
             myColor.setAlpha(255);
     }
 
+//! [8] //! [9]
     switch (colorSaturationType) {
         case SaturationVTilt:
             myColor.setHsv(hue, vValue, value, alpha);
@@ -189,17 +226,19 @@ void TabletCanvas::updateBrush(QTabletEvent *event)
             ;
     }
 
+//! [9] //! [10]
     switch (lineWidthType) {
         case LineWidthPressure:
             myPen.setWidthF(event->pressure() * 10 + 1);
             break;
         case LineWidthTilt:
-            myPen.setWidthF(max(abs(vValue - 127), abs(hValue - 127)) / 12);
+            myPen.setWidthF(maximum(abs(vValue - 127), abs(hValue - 127)) / 12);
             break;
         default:
             myPen.setWidthF(1);
     }
 
+//! [10] //! [11]
     if (event->pointerType() == QTabletEvent::Eraser) {
         myBrush.setColor(Qt::white);
         myPen.setColor(Qt::white);
@@ -209,3 +248,10 @@ void TabletCanvas::updateBrush(QTabletEvent *event)
         myPen.setColor(myColor);
     }
 }
+//! [11]
+
+void TabletCanvas::resizeEvent(QResizeEvent *event)
+{
+    initImage();
+    polyLine[0] = polyLine[1] = polyLine[2] = QPoint();
+}
