@@ -1,53 +1,54 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the qmake application of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "mingw_make.h"
 #include "option.h"
+#include "meta.h"
 #include <qregexp.h>
 #include <qdir.h>
 #include <stdlib.h>
 #include <time.h>
 
+QT_BEGIN_NAMESPACE
+
 MingwMakefileGenerator::MingwMakefileGenerator() : Win32MakefileGenerator(), init_flag(false)
 {
     if (Option::shellPath.isEmpty())
@@ -94,20 +95,25 @@ bool MingwMakefileGenerator::findLibraries()
     QStringList::Iterator it = l.begin();
     while (it != l.end()) {
         if ((*it).startsWith("-l")) {
-            QString steam = (*it).mid(2);
+            QString steam = (*it).mid(2), out;
             QString suffix;
             if (!project->isEmpty("QMAKE_" + steam.toUpper() + "_SUFFIX"))
                 suffix = project->first("QMAKE_" + steam.toUpper() + "_SUFFIX");
-            QString extension;
             for (QList<QMakeLocalFileName>::Iterator dir_it = dirs.begin(); dir_it != dirs.end(); ++dir_it) {
+                QString extension;
                 int ver = findHighestVersion((*dir_it).local(), steam, "dll.a|a");
-                if (ver != -1) {
+                if (ver != -1)
                     extension += QString::number(ver);
-                    break;
+                extension += suffix;
+                if(QMakeMetaInfo::libExists((*dir_it).local() + Option::dir_sep + steam) ||
+                    exists((*dir_it).local() + Option::dir_sep + steam + extension + ".a") ||
+                    exists((*dir_it).local() + Option::dir_sep + steam + extension + ".dll.a")) {
+                        out = (*it) + extension;
+                        break;
                 }
             }
-	        extension += suffix;
-	        (*it) += extension;
+            if (!out.isEmpty()) // We assume if it never finds it that its correct
+                (*it) = out;
 	    } else if((*it).startsWith("-L")) {
             dirs.append(QMakeLocalFileName((*it).mid(2)));
         }
@@ -396,10 +402,15 @@ void MingwMakefileGenerator::writeBuildRulesPart(QTextStream &t)
 void MingwMakefileGenerator::writeRcFilePart(QTextStream &t)
 {
     const QString rc_file = fileFixify(project->first("RC_FILE"));
+
+    QString incPathStr = fileInfo(rc_file).path();
+    if (incPathStr != "." && QDir::isRelativePath(incPathStr))
+        incPathStr.prepend("./");
+
     if (!rc_file.isEmpty()) {
         t << escapeDependencyPath(var("RES_FILE")) << ": " << rc_file << "\n\t"
           << var("QMAKE_RC") << " -i " << rc_file << " -o " << var("RES_FILE") 
-	  << " --include-dir=" << fileInfo(rc_file).path() << endl << endl;
+          << " --include-dir=" << incPathStr << endl << endl;
     }
 }
 
@@ -446,3 +457,4 @@ QStringList &MingwMakefileGenerator::findDependencies(const QString &file)
     return aList;
 }
 
+QT_END_NAMESPACE
