@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.1, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -50,6 +48,8 @@
 #include <ctype.h>
 #include <stdlib.h>
 
+QT_BEGIN_NAMESPACE
+
 /*!
     \class QDataStream
     \reentrant
@@ -79,24 +79,11 @@
 
     Example (write binary data to a stream):
 
-    \code
-        QFile file("file.dat");
-        file.open(QIODevice::WriteOnly);
-        QDataStream out(&file);   // we will serialize the data into the file
-        out << "the answer is";   // serialize a string
-        out << (qint32)42;        // serialize an integer
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 0
 
     Example (read binary data from a stream):
 
-    \code
-        QFile file("file.dat");
-        file.open(QIODevice::ReadOnly);
-        QDataStream in(&file);    // read the data serialized from the file
-        QString str;
-        qint32 a;
-        in >> str >> a;           // extract "the answer is" and 42
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 1
 
     Each item written to the stream is written in a predefined binary
     format that varies depending on the item's type. Supported Qt
@@ -131,9 +118,7 @@
     compatibility, you can hardcode the version number in the
     application:
 
-    \code
-        stream.setVersion(QDataStream::Qt_4_0);
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 2
 
     If you are producing a new binary data format, such as a file
     format for documents created by your application, you could use a
@@ -141,53 +126,11 @@
     would write a brief header containing a magic string and a version
     number to give yourself room for future expansion. For example:
 
-    \code
-        QFile file("file.xxx");
-        file.open(QIODevice::WriteOnly);
-        QDataStream out(&file);
-
-        // Write a header with a "magic number" and a version
-        out << (quint32)0xA0B0C0D0;
-        out << (qint32)123;
-
-        out.setVersion(QDataStream::Qt_4_0);
-
-        // Write the data
-        out << lots_of_interesting_data;
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 3
 
     Then read it in with:
 
-    \code
-        QFile file("file.xxx");
-        file.open(QIODevice::ReadOnly);
-        QDataStream in(&file);
-
-        // Read and check the header
-        quint32 magic;
-        in >> magic;
-        if (magic != 0xA0B0C0D0)
-            return XXX_BAD_FILE_FORMAT;
-
-        // Read the version
-        qint32 version;
-        in >> version;
-        if (version < 100)
-            return XXX_BAD_FILE_TOO_OLD;
-        if (version > 123)
-            return XXX_BAD_FILE_TOO_NEW;
-
-        if (version <= 110)
-            in.setVersion(QDataStream::Qt_3_2);
-        else
-            in.setVersion(QDataStream::Qt_4_0);
-
-        // Read the data
-        in >> lots_of_interesting_data;
-        if (version >= 120)
-            in >> data_new_in_XXX_version_1_2;
-        in >> other_interesting_data;
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 4
 
     You can select which byte order to use when serializing data. The
     default setting is big endian (MSB first). Changing it to little
@@ -212,6 +155,31 @@
     data, followed by the data. Note that any encoding/decoding of
     the data (apart from the length quint32) must be done by you.
 
+    \target Serializing Qt Classes
+    \section1 Reading and writing other Qt classes.
+
+    In addition to the overloaded stream operators documented here,
+    any Qt classes that you might want to serialize to a QDataStream
+    will have appropriate stream operators declared as non-member of
+    the class:
+
+    \code
+    QDataStream &operator<<(QDataStream &, const QXxx &);
+    QDataStream &operator>>(QDataStream &, QXxx &);
+    \endcode
+
+    For example, here are the stream operators declared as non-members
+    of the QImage class:
+
+    \code
+    QDataStream & operator<< (QDataStream& stream, const QImage& image);
+    QDataStream & operator>> (QDataStream& stream, QImage& image);
+    \endcode
+
+    To see if your favorite Qt class has similar stream operators
+    defined, check the \bold {Related Non-Members} section of the
+    class's documentation page.
+
     \sa QTextStream QVariant
 */
 
@@ -221,7 +189,7 @@
     The byte order used for reading/writing the data.
 
     \value BigEndian Most significant byte first (the default)
-    \value LittleEndian Less significant byte first
+    \value LittleEndian Least significant byte first
 */
 
 /*!
@@ -254,10 +222,10 @@
 #endif
 
 enum {
-    DefaultStreamVersion = QDataStream::Qt_4_3
+    DefaultStreamVersion = QDataStream::Qt_4_5
 };
 
-// ### 4.0: when streaming invalid QVariants, just the type should
+// ### 5.0: when streaming invalid QVariants, just the type should
 // be written, no "data" after it
 
 /*!
@@ -310,6 +278,9 @@ QDataStream::QDataStream(QIODevice *d)
 QDataStream::QDataStream(QByteArray *a, int mode)
 {
     QBuffer *buf = new QBuffer(a);
+#ifndef QT_NO_QOBJECT
+    buf->blockSignals(true);
+#endif
     buf->open(QIODevice::OpenMode(mode));
     dev = buf;
     owndev = true;
@@ -336,6 +307,9 @@ QDataStream::QDataStream(QByteArray *a, int mode)
 QDataStream::QDataStream(QByteArray *a, QIODevice::OpenMode flags)
 {
     QBuffer *buf = new QBuffer(a);
+#ifndef QT_NO_QOBJECT
+    buf->blockSignals(true);
+#endif
     buf->open(flags);
     dev = buf;
     owndev = true;
@@ -356,6 +330,9 @@ QDataStream::QDataStream(QByteArray *a, QIODevice::OpenMode flags)
 QDataStream::QDataStream(const QByteArray &a)
 {
     QBuffer *buf = new QBuffer;
+#ifndef QT_NO_QOBJECT
+    buf->blockSignals(true);
+#endif
     buf->setData(a);
     buf->open(QIODevice::ReadOnly);
     dev = buf;
@@ -408,9 +385,9 @@ void QDataStream::setDevice(QIODevice *d)
 }
 
 /*!
-    Unsets the I/O device. This is the same as calling setDevice(0).
-
-    \sa device(), setDevice()
+    \obsolete
+    Unsets the I/O device.
+    Use setDevice(0) instead.
 */
 
 void QDataStream::unsetDevice()
@@ -536,6 +513,9 @@ void QDataStream::setByteOrder(ByteOrder bo)
     \value Qt_4_1 Version 7 (Qt 4.0, Qt 4.1)
     \value Qt_4_2 Version 8 (Qt 4.2)
     \value Qt_4_3 Version 9 (Qt 4.3)
+    \value Qt_4_4 Version 10 (Qt 4.4)
+    \value Qt_4_5 Version 10 (Qt 4.5)
+    \omitvalue Qt_4_6
 
     \sa setVersion(), version()
 */
@@ -567,23 +547,22 @@ void QDataStream::setByteOrder(ByteOrder bo)
 
     \table
     \header \i Qt Version       \i QDataStream Version
-    \row \i Qt 4.2              \i 8
-    \row \i Qt 4.0              \i 7
-    \row \i Qt 3.3              \i 6
-    \row \i Qt 3.1, 3.2         \i 5
-    \row \i Qt 3.0              \i 4
-    \row \i Qt 2.1, 2.2, 2.3    \i 3
-    \row \i Qt 2.0              \i 2
-    \row \i Qt 1.x              \i 1
+    \row \i Qt 4.4                  \i 10
+    \row \i Qt 4.3                  \i 9
+    \row \i Qt 4.2                  \i 8
+    \row \i Qt 4.0, 4.1            \i 7
+    \row \i Qt 3.3                  \i 6
+    \row \i Qt 3.1, 3.2             \i 5
+    \row \i Qt 3.0                  \i 4
+    \row \i Qt 2.1, 2.2, 2.3      \i 3
+    \row \i Qt 2.0                  \i 2
+    \row \i Qt 1.x                  \i 1
     \endtable
 
     The \l Version enum provides symbolic constants for the different
     versions of Qt. For example:
 
-    \code
-        QDataStream out(file);
-        out.setVersion(QDataStream::Qt_4_0);
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qdatastream.cpp 5
 
     \sa version(), Version
 */
@@ -1252,8 +1231,10 @@ int QDataStream::skipRawData(int len)
         }
         return sumRead;
     } else {
-        quint64 pos = dev->pos();
-        len = qMin(int(dev->size() - pos), len);
+        qint64 pos = dev->pos();
+        qint64 size = dev->size();
+        if (pos + len > size)
+            len = size - pos;
         if (!dev->seek(pos + len))
             return -1;
         return len;
@@ -1274,4 +1255,6 @@ int QDataStream::skipRawData(int len)
 */
 #endif
 
+QT_END_NAMESPACE
+
 #endif // QT_NO_DATASTREAM
