@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -40,8 +45,11 @@
 #include <qdebug.h>
 #include <qstring.h>
 #include <ctype.h>
+#if !defined(Q_OS_WINCE)
 #include <errno.h>
+#endif
 
+QT_BEGIN_NAMESPACE
 /*
     Returns a human readable representation of the first \a len
     characters in \a data.
@@ -71,6 +79,9 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
 
     return out;
 }
+
+QT_END_NAMESPACE
+
 #endif
 
 #include "qprocess.h"
@@ -88,6 +99,28 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
 
 #ifndef QT_NO_PROCESS
 
+QT_BEGIN_NAMESPACE
+
+void QProcessPrivate::Channel::clear()
+{
+    switch (type) {
+    case PipeSource:
+        Q_ASSERT(process);
+        process->stdinChannel.type = Normal;
+        process->stdinChannel.process = 0;
+        break;
+    case PipeSink:
+        Q_ASSERT(process);
+        process->stdoutChannel.type = Normal;
+        process->stdoutChannel.process = 0;
+        break;
+    }
+
+    type = Normal;
+    file.clear();
+    process = 0;
+}
+
 /*!
     \class QProcess
 
@@ -102,14 +135,10 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
     To start a process, pass the name and command line arguments of
     the program you want to run as arguments to start(). For example:
 
-    \quotefromfile snippets/qprocess/qprocess-simpleexecution.cpp
-    \skipto parent
-    \printline parent
+    \snippet doc/src/snippets/qprocess/qprocess-simpleexecution.cpp 0
     \dots
-    \skipto program
-    \printline program
-    \skipto QStringList
-    \printuntil start
+    \snippet doc/src/snippets/qprocess/qprocess-simpleexecution.cpp 1
+    \snippet doc/src/snippets/qprocess/qprocess-simpleexecution.cpp 2
 
     QProcess then enters the \l Starting state, and when the program
     has started, QProcess enters the \l Running state and emits
@@ -124,6 +153,8 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
     used as an input source for QXmlReader, or for generating data to
     be uploaded using QFtp.
 
+    \note On Windows CE, reading and writing to a process is not supported.
+
     When the process exits, QProcess reenters the \l NotRunning state
     (the initial state), and emits finished().
 
@@ -135,6 +166,8 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
     can also call error() to find the type of error that occurred
     last, and state() to find the current process state.
 
+    \section1 Communicating via Channels
+
     Processes have two predefined output channels: The standard
     output channel (\c stdout) supplies regular console output, and
     the standard error channel (\c stderr) usually supplies the
@@ -170,6 +203,8 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
     setWorkingDirectory(). By default, processes are run in the
     current working directory of the calling process.
 
+    \section1 Synchronous Process API
+
     QProcess provides a set of functions which allow it to be used
     without an event loop, by suspending the calling thread until
     certain signals are emitted:
@@ -193,9 +228,16 @@ static QByteArray qt_prettyDebug(const char *data, int len, int maxSize)
     The following example runs \c gzip to compress the string "Qt
     rocks!", without an event loop:
 
-    \quotefromfile snippets/process/process.cpp
-    \skipto QProcess gzip;
-    \printuntil result = gzip.readAll();
+    \snippet doc/src/snippets/process/process.cpp 0
+
+    \section1 Notes for Windows Users 
+
+    Some Windows commands (for example, \c dir) are not provided by
+    separate applications, but by the command interpreter itself.
+    If you attempt to use QProcess to execute these commands directly,
+    it won't work. One possible solution is to execute the command
+    interpreter itself (\c{cmd.exe} on some Windows systems), and ask
+    the interpreter to execute the desired command.
 
     \sa QBuffer, QFile, QTcpSocket
 */
@@ -410,7 +452,7 @@ QProcessPrivate::~QProcessPrivate()
 */
 void QProcessPrivate::cleanup()
 {
-    processState = QProcess::NotRunning;
+    q_func()->setProcessState(QProcess::NotRunning);
 #ifdef Q_OS_WIN
     if (pid) {
         CloseHandle(pid->hThread);
@@ -420,7 +462,7 @@ void QProcessPrivate::cleanup()
     }
     if (processFinishedNotifier) {
         processFinishedNotifier->setEnabled(false);
-        delete processFinishedNotifier;
+        qDeleteInEventHandler(processFinishedNotifier);
         processFinishedNotifier = 0;
     }
 
@@ -431,31 +473,31 @@ void QProcessPrivate::cleanup()
 
     if (stdoutChannel.notifier) {
         stdoutChannel.notifier->setEnabled(false);
-        delete stdoutChannel.notifier;
+        qDeleteInEventHandler(stdoutChannel.notifier);
         stdoutChannel.notifier = 0;
     }
     if (stderrChannel.notifier) {
         stderrChannel.notifier->setEnabled(false);
-        delete stderrChannel.notifier;
+        qDeleteInEventHandler(stderrChannel.notifier);
         stderrChannel.notifier = 0;
     }
     if (stdinChannel.notifier) {
         stdinChannel.notifier->setEnabled(false);
-        delete stdinChannel.notifier;
+        qDeleteInEventHandler(stdinChannel.notifier);
         stdinChannel.notifier = 0;
     }
     if (startupSocketNotifier) {
         startupSocketNotifier->setEnabled(false);
-        delete startupSocketNotifier;
+        qDeleteInEventHandler(startupSocketNotifier);
         startupSocketNotifier = 0;
     }
     if (deathNotifier) {
         deathNotifier->setEnabled(false);
-        delete deathNotifier;
+        qDeleteInEventHandler(deathNotifier);
         deathNotifier = 0;
     }
     if (notifier) {
-        delete notifier;
+        qDeleteInEventHandler(notifier);
         notifier = 0;
     }
     destroyPipe(stdoutChannel.pipe);
@@ -488,7 +530,7 @@ bool QProcessPrivate::_q_canReadStandardOutput()
     qint64 readBytes = readFromStdout(ptr, available);
     if (readBytes == -1) {
         processError = QProcess::ReadError;
-        q->setErrorString(QT_TRANSLATE_NOOP(QProcess, QLatin1String("Error reading from process")));
+        q->setErrorString(QProcess::tr("Error reading from process"));
         emit q->error(processError);
 #if defined QPROCESS_DEBUG
         qDebug("QProcessPrivate::canReadStandardOutput(), failed to read from the process");
@@ -540,7 +582,7 @@ bool QProcessPrivate::_q_canReadStandardError()
     qint64 readBytes = readFromStderr(ptr, available);
     if (readBytes == -1) {
         processError = QProcess::ReadError;
-        q->setErrorString(QT_TRANSLATE_NOOP(QProcess, QLatin1String("Error reading from process")));
+        q->setErrorString(QProcess::tr("Error reading from process"));
         emit q->error(processError);
         return false;
     }
@@ -587,8 +629,8 @@ bool QProcessPrivate::_q_canWrite()
     if (written < 0) {
         destroyPipe(stdinChannel.pipe);
         processError = QProcess::WriteError;
-        q->setErrorString(QT_TRANSLATE_NOOP(QProcess, QLatin1String("Error writing to process")));
-#if defined QPROCESS_DEBUG
+        q->setErrorString(QProcess::tr("Error writing to process"));
+#if defined(QPROCESS_DEBUG) && !defined(Q_OS_WINCE)
         qDebug("QProcessPrivate::canWrite(), failed to write (%s)", strerror(errno));
 #endif
         emit q->error(processError);
@@ -645,7 +687,7 @@ bool QProcessPrivate::_q_processDied()
         return true;
     }
     dying = true;
-    
+
     // in case there is data in the pipe line and this slot by chance
     // got called before the read notifications, call these two slots
     // so the data is made available before the process dies.
@@ -657,7 +699,7 @@ bool QProcessPrivate::_q_processDied()
     if (crashed) {
         exitStatus = QProcess::CrashExit;
         processError = QProcess::Crashed;
-        q->setErrorString(QT_TRANSLATE_NOOP(QProcess, QLatin1String("Process crashed")));
+        q->setErrorString(QProcess::tr("Process crashed"));
         emit q->error(processError);
     }
 
@@ -665,9 +707,13 @@ bool QProcessPrivate::_q_processDied()
 
     cleanup();
 
-    processState = QProcess::NotRunning;
-    emit q->stateChanged(processState);
     if (wasRunning) {
+        // we received EOF now:
+        emit q->readChannelFinished();
+        // in the future:
+        //emit q->standardOutputClosed();
+        //emit q->standardErrorClosed();
+
         emit q->finished(exitCode);
         emit q->finished(exitCode, exitStatus);
     }
@@ -689,12 +735,12 @@ bool QProcessPrivate::_q_startupNotification()
     if (startupSocketNotifier)
         startupSocketNotifier->setEnabled(false);
     if (processStarted()) {
-        processState = QProcess::Running;
+        q->setProcessState(QProcess::Running);
         emit q->started();
         return true;
     }
 
-    processState = QProcess::NotRunning;
+    q->setProcessState(QProcess::NotRunning);
     processError = QProcess::FailedToStart;
     emit q->error(processError);
 #ifdef Q_OS_UNIX
@@ -714,9 +760,12 @@ void QProcessPrivate::closeWriteChannel()
     qDebug("QProcessPrivate::closeWriteChannel()");
 #endif
     if (stdinChannel.notifier) {
+        extern void qDeleteInEventHandler(QObject *o);
         stdinChannel.notifier->setEnabled(false);
-        delete stdinChannel.notifier;
-        stdinChannel.notifier = 0;
+        if (stdinChannel.notifier) {
+            qDeleteInEventHandler(stdinChannel.notifier);
+            stdinChannel.notifier = 0;
+        } 
     }
 #ifdef Q_OS_WIN
     // ### Find a better fix, feeding the process little by little
@@ -803,16 +852,7 @@ QProcess::ProcessChannelMode QProcess::processChannelMode() const
     error channels to the \a mode specified.
     This mode will be used the next time start() is called. For example:
 
-    \code
-        QProcess builder;
-        builder.setProcessChannelMode(QProcess::MergedChannels);
-        builder.start("make", QStringList() << "-j2");
-
-        if (!builder.waitForFinished())
-            qDebug() << "Make failed:" << builder.errorString();
-        else
-            qDebug() << "Make output:" << builder.readAll();
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 0
 
     \sa readChannelMode(), ProcessChannelMode, setReadChannel()
 */
@@ -889,13 +929,7 @@ void QProcess::closeReadChannel(ProcessChannel channel)
     Unix and Windows. But it will not display the text data until
     QProcess's write channel has been closed. Example:
 
-    \code
-        QProcess more;
-        more.start("more");
-        more.write("Text to display");
-        more.closeWriteChannel();
-        // QProcess will emit readyRead() once "more" starts printing
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 1
 
     The write channel is implicitly opened when start() is called.
 
@@ -997,20 +1031,10 @@ void QProcess::setStandardErrorFile(const QString &fileName, OpenMode mode)
     destination process' standard input.
 
     The following shell command:
-    \code
-        command1 | command2
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 2
 
     Can be accomplished with QProcesses with the following code:
-    \code
-        QProcess process1;
-        QProcess process2;
-
-        process1.setStandardOutputProcess(process2);
-
-        process1.start("command1");
-        process2.start("command2");
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 3
 */
 void QProcess::setStandardOutputProcess(QProcess *destination)
 {
@@ -1021,8 +1045,11 @@ void QProcess::setStandardOutputProcess(QProcess *destination)
 }
 
 /*!
-    Returns the working directory that the QProcess will enter before
-    the program has started.
+    If QProcess has been assigned a working directory, this function returns
+    the working directory that the QProcess will enter before the program has
+    started. Otherwise, (i.e., no directory has been assigned,) an empty
+    string is returned, and QProcess will use the application's current
+    working directory instead.
 
     \sa setWorkingDirectory()
 */
@@ -1071,7 +1098,7 @@ bool QProcess::canReadLine() const
 }
 
 /*!
-    Closes all communication with the process. After calling this
+    Closes all communication with the process and kills it. After calling this
     function, QProcess will no longer emit readyRead(), and data can no
     longer be read or written.
 */
@@ -1082,7 +1109,7 @@ void QProcess::close()
         ;
     kill();
     waitForFinished(-1);
-    setOpenMode(QIODevice::NotOpen);
+    QIODevice::close();
 }
 
 /*! \reimp
@@ -1162,9 +1189,7 @@ QProcess::ProcessState QProcess::state() const
     For example, the following code adds the \c{C:\\BIN} directory to the list of
     executable paths (\c{PATHS}) on Windows:
 
-    \quotefromfile snippets/qprocess-environment/main.cpp
-    \skipto QProcess process;
-    \printuntil process.start
+    \snippet doc/src/snippets/qprocess-environment/main.cpp 0
 
     \sa environment(), systemEnvironment()
 */
@@ -1180,6 +1205,9 @@ void QProcess::setEnvironment(const QStringList &environment)
     using setEnvironment(). If no environment has been set, the
     environment of the calling process will be used.
 
+    \note The environment settings are ignored on Windows CE,
+    as there is no concept of an environment.
+
     \sa setEnvironment(), systemEnvironment()
 */
 QStringList QProcess::environment() const
@@ -1213,7 +1241,7 @@ bool QProcess::waitForStarted(int msecs)
     if (d->processState == QProcess::Starting) {
         if (!d->waitForStarted(msecs))
             return false;
-        d->processState = QProcess::Running;
+        setProcessState(QProcess::Running);
         emit started();
     }
     return d->processState == QProcess::Running;
@@ -1298,7 +1326,10 @@ bool QProcess::waitForFinished(int msecs)
 void QProcess::setProcessState(ProcessState state)
 {
     Q_D(QProcess);
+    if (d->processState == state)
+        return;
     d->processState = state;
+    emit stateChanged(state);
 }
 
 /*!
@@ -1307,30 +1338,12 @@ void QProcess::setProcessState(ProcessState state)
     \e execve()). Reimplement this function to do last minute initialization
     of the child process. Example:
 
-    \code
-        class SandboxProcess : public QProcess
-        {
-            ...
-         protected:
-             void setupChildProcess();
-            ...
-        };
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 4
 
-        void SandboxProcess::setupChildProcess()
-        {
-            // Drop all privileges in the child process, and enter
-            // a chroot jail.
-        #if defined Q_OS_UNIX
-            ::setgroups(0, 0);
-            ::chroot("/etc/safe");
-            ::chdir("/");
-            ::setgid(safeGid);
-            ::setuid(safeUid);
-            ::umask(0);
-        #endif
-        }
-
-    \endcode
+    You cannot exit the process (by calling exit(), for instance) from
+    this function. If you need to stop the program before it starts
+    execution, your workaround is to emit finished() and then call
+    exit().
 
     \warning This function is called by QProcess on Unix and Mac OS X
     only. On Windows, it is not called.
@@ -1348,7 +1361,7 @@ qint64 QProcess::readData(char *data, qint64 maxlen)
                               ? &d->errorReadBuffer
                               : &d->outputReadBuffer;
 
-    if (maxlen == 1) {
+    if (maxlen == 1 && !readBuffer->isEmpty()) {
         int c = readBuffer->getChar();
         if (c == -1) {
 #if defined QPROCESS_DEBUG
@@ -1380,6 +1393,8 @@ qint64 QProcess::readData(char *data, qint64 maxlen)
     qDebug("QProcess::readData(%p \"%s\", %lld) == %lld",
            data, qt_prettyDebug(data, readSoFar, 16).constData(), maxlen, readSoFar);
 #endif
+    if (!readSoFar && d->processState == QProcess::NotRunning)
+        return -1;              // EOF
     return readSoFar;
 }
 
@@ -1389,6 +1404,15 @@ qint64 QProcess::writeData(const char *data, qint64 len)
 {
     Q_D(QProcess);
 
+#if defined(Q_OS_WINCE)
+    Q_UNUSED(data);
+    Q_UNUSED(len);
+    d->processError = QProcess::WriteError;
+    setErrorString(tr("Error writing to process"));
+    emit error(d->processError);
+    return -1;
+#endif
+
     if (d->stdinChannel.closed) {
 #if defined QPROCESS_DEBUG
     qDebug("QProcess::writeData(%p \"%s\", %lld) == 0 (write channel closing)",
@@ -1458,9 +1482,12 @@ QByteArray QProcess::readAllStandardError()
     process starts successfully, QProcess will emit started();
     otherwise, error() will be emitted.
 
-    On Windows, arguments that contain spaces are wrapped in quotes.
+    Note that arguments that contain spaces are not passed to the
+    process as separate arguments.
 
-    Note: processes are started asynchronously, which means the started()
+    \bold{Windows:} Arguments that contain spaces are wrapped in quotes.
+
+    \note Processes are started asynchronously, which means the started()
     and error() signals may be delayed. Call waitForStarted() to make
     sure the process has started (or has failed to start) and those signals
     have been emitted.
@@ -1490,7 +1517,7 @@ void QProcess::start(const QString &program, const QStringList &arguments, OpenM
         mode &= ~ReadOnly;      // not open for reading
     if (mode == 0)
         mode = Unbuffered;
-    setOpenMode(mode);
+    QIODevice::open(mode);
 
     d->stdinChannel.closed = false;
     d->stdoutChannel.closed = false;
@@ -1555,30 +1582,19 @@ static QStringList parseCombinedArgString(const QString &program)
     arguments. The arguments are separated by one or more
     spaces. For example:
 
-    \code
-        QProcess process;
-        process.start("del /s *.txt");
-        // same as process.start("del", QStringList() << "/s" << "*.txt");
-        ...
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 5
 
     The \a program string can also contain quotes, to ensure that arguments
     containing spaces are correctly supplied to the new process. For example:
 
-    \code
-        QProcess process;
-        process.start("dir \"My Documents\"");
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 6
 
     Note that, on Windows, quotes need to be both escaped and quoted.
     For example, the above code would be specified in the following
     way to ensure that \c{"My Documents"} is used as the argument to
     the \c dir executable:
 
-    \code
-        QProcess process;
-        process.start("dir \"\"\"My Documents\"\"\"");
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 7
 
     The OpenMode is set to \a mode.
 */
@@ -1694,11 +1710,14 @@ int QProcess::execute(const QString &program)
     otherwise returns false. If the calling process exits, the
     detached process will continue to live.
 
-    On Unix, the started process will run in its own session and act
-    like a daemon. On Windows, it will run as a regular standalone
-    process.
+    Note that arguments that contain spaces are not passed to the
+    process as separate arguments.
 
-    On Windows, arguments that contain spaces are wrapped in quotes.
+    \bold{Unix:} The started process will run in its own session and act
+    like a daemon.
+
+    \bold{Windows:} Arguments that contain spaces are wrapped in quotes.
+    The started process will run as a regular standalone process.
 
     The process will be started in the directory \a workingDirectory.
 
@@ -1717,16 +1736,19 @@ bool QProcess::startDetached(const QString &program,
 }
 
 /*!
-    Starts the program \a program with the arguments \a arguments in a
+    Starts the program \a program with the given \a arguments in a
     new process, and detaches from it. Returns true on success;
     otherwise returns false. If the calling process exits, the
     detached process will continue to live.
 
-    On Unix, the started process will run in its own session and act
-    like a daemon. On Windows, it will run as a regular standalone
-    process.
+    Note that arguments that contain spaces are not passed to the
+    process as separate arguments.
 
-    On Windows, arguments that contain spaces are wrapped in quotes.
+    \bold{Unix:} The started process will run in its own session and act
+    like a daemon.
+
+    \bold{Windows:} Arguments that contain spaces are wrapped in quotes.
+    The started process will run as a regular standalone process.
 */
 bool QProcess::startDetached(const QString &program,
 			     const QStringList &arguments)
@@ -1754,12 +1776,17 @@ bool QProcess::startDetached(const QString &program)
     return QProcessPrivate::startDetached(prog, args);
 }
 
+QT_BEGIN_INCLUDE_NAMESPACE
 #ifdef Q_OS_MAC
 # include <crt_externs.h>
 # define environ (*_NSGetEnviron())
+#elif defined(Q_OS_WINCE)
+  static char *qt_wince_environ[] = { 0 };
+#define environ qt_wince_environ
 #elif !defined(Q_OS_WIN)
   extern char **environ;
 #endif
+QT_END_INCLUDE_NAMESPACE
 
 /*!
     \since 4.1
@@ -1767,11 +1794,7 @@ bool QProcess::startDetached(const QString &program)
     Returns the environment of the calling process as a list of
     key=value pairs. Example:
 
-    \code
-        QStringList environment = QProcess::systemEnvironment();
-        // environment = {"PATH=/usr/bin:/usr/local/bin",
-                          "USER=greg", "HOME=/home/greg"}
-    \endcode
+    \snippet doc/src/snippets/code/src_corelib_io_qprocess.cpp 8
 
     \sa environment(), setEnvironment()
 */
@@ -1796,6 +1819,9 @@ QStringList QProcess::systemEnvironment()
     \sa QProcess::pid()
 */
 
+QT_END_NAMESPACE
+
 #include "moc_qprocess.cpp"
 
 #endif // QT_NO_PROCESS
+
