@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -86,22 +84,22 @@ QT_BEGIN_NAMESPACE
 
     Adding a Q_DECLARE_METATYPE() makes the type known to all template
     based functions, including QVariant. Note that if you intend to
-    use the type in \e queued signal and slot connections, you also
-    have to call qRegisterMetaType() since such connections are
-    resolved at runtime.
+    use the type in \e queued signal and slot connections or in
+    QObject's property system, you also have to call
+    qRegisterMetaType() since the names are resolved at runtime.
 
     This example shows a typical use case of Q_DECLARE_METATYPE():
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 0
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 0
 
     If \c MyStruct is in a namespace, the Q_DECLARE_METATYPE() macro
     has to be outside the namespace:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 1
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 1
 
     Since \c{MyStruct} is now known to QMetaType, it can be used in QVariant:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 2
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 2
 
     \sa qRegisterMetaType()
 */
@@ -147,6 +145,7 @@ QT_BEGIN_NAMESPACE
     \value QTextLength QTextLength
     \value QStringList QStringList
     \value QVariantMap QVariantMap
+    \value QVariantHash QVariantHash
     \value QIcon QIcon
     \value QPen QPen
     \value QLineF QLineF
@@ -206,7 +205,7 @@ QT_BEGIN_NAMESPACE
     The following code allocates and destructs an instance of
     \c{MyClass}:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 3
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 3
 
     If we want the stream operators \c operator<<() and \c
     operator>>() to work on QVariant objects that store custom types,
@@ -248,6 +247,7 @@ static const struct { const char * typeName; int type; } types[] = {
     {"QPoint", QMetaType::QPoint},
     {"QPointF", QMetaType::QPointF},
     {"QRegExp", QMetaType::QRegExp},
+    {"QVariantHash", QMetaType::QVariantHash},
 
     /* All GUI types */
     {"QColorGroup", 63},
@@ -299,6 +299,7 @@ static const struct { const char * typeName; int type; } types[] = {
     {"quint64", QMetaType::ULongLong},
     {"QList<QVariant>", QMetaType::QVariantList},
     {"QMap<QString,QVariant>", QMetaType::QVariantMap},
+    {"QHash<QString,QVariant>", QMetaType::QVariantHash},
     // let QMetaTypeId2 figure out the type at compile time
     {"qreal", QMetaTypeId2<qreal>::MetaType},
 
@@ -440,10 +441,10 @@ int QMetaType::registerType(const char *typeName, Destructor destructor,
     return idx;
 }
 
-/*! 
+/*!
     \since 4.4
 
-    Unregisters a user type, with \a typeName. 
+    Unregisters a user type, with \a typeName.
 
     \sa type(), typeName()
  */
@@ -577,6 +578,9 @@ bool QMetaType::save(QDataStream &stream, int type, const void *data)
     case QMetaType::QVariantMap:
         stream << *static_cast<const NS(QVariantMap)*>(data);
         break;
+    case QMetaType::QVariantHash:
+        stream << *static_cast<const NS(QVariantHash)*>(data);
+        break;
     case QMetaType::QVariantList:
         stream << *static_cast<const NS(QVariantList)*>(data);
         break;
@@ -766,6 +770,9 @@ bool QMetaType::load(QDataStream &stream, int type, void *data)
     case QMetaType::QVariantMap:
         stream >> *static_cast< NS(QVariantMap)*>(data);
         break;
+    case QMetaType::QVariantHash:
+        stream >> *static_cast< NS(QVariantHash)*>(data);
+        break;
     case QMetaType::QVariantList:
         stream >> *static_cast< NS(QVariantList)*>(data);
         break;
@@ -922,6 +929,8 @@ void *QMetaType::construct(int type, const void *copy)
 #ifndef QT_BOOTSTRAPPED
         case QMetaType::QVariantMap:
             return new NS(QVariantMap)(*static_cast<const NS(QVariantMap)*>(copy));
+        case QMetaType::QVariantHash:
+            return new NS(QVariantHash)(*static_cast<const NS(QVariantHash)*>(copy));
         case QMetaType::QVariantList:
             return new NS(QVariantList)(*static_cast<const NS(QVariantList)*>(copy));
 #endif
@@ -1011,6 +1020,8 @@ void *QMetaType::construct(int type, const void *copy)
 #ifndef QT_BOOTSTRAPPED
         case QMetaType::QVariantMap:
             return new NS(QVariantMap);
+        case QMetaType::QVariantHash:
+            return new NS(QVariantHash);
         case QMetaType::QVariantList:
             return new NS(QVariantList);
 #endif
@@ -1144,6 +1155,9 @@ void QMetaType::destroy(int type, void *data)
     case QMetaType::QVariantMap:
         delete static_cast< NS(QVariantMap)* >(data);
         break;
+    case QMetaType::QVariantHash:
+        delete static_cast< NS(QVariantHash)* >(data);
+        break;
     case QMetaType::QVariantList:
         delete static_cast< NS(QVariantList)* >(data);
         break;
@@ -1249,7 +1263,7 @@ void QMetaType::destroy(int type, void *data)
 
     This example registers the class \c{MyClass}:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 4
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 4
 
     \sa qRegisterMetaTypeStreamOperators(), QMetaType::isRegistered(),
         Q_DECLARE_METATYPE()
@@ -1267,11 +1281,11 @@ void QMetaType::destroy(int type, void *data)
     QMetaType::save(). These functions are used when streaming a
     QVariant.
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 5
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 5
 
     The stream operators should have the following signatures:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 6
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 6
 
     \sa qRegisterMetaType(), QMetaType::isRegistered(), Q_DECLARE_METATYPE()
 */
@@ -1300,13 +1314,13 @@ void QMetaType::destroy(int type, void *data)
 
     Example:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 7
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 7
 
     To use the type \c T in QVariant, using Q_DECLARE_METATYPE() is
     sufficient. To use the type \c T in queued signal and slot connections,
     \c{qRegisterMetaType<T>()} must be called before the first connection
     is established.
-    
+
     Also, to use type \c T with the QObject::property() API,
     \c{qRegisterMetaType<T>()} must be called before it is used, typically
     in the constructor of the class that uses \c T, or in the \c{main()}
@@ -1326,7 +1340,7 @@ void QMetaType::destroy(int type, void *data)
 
     Typical usage:
 
-    \snippet doc/src/snippets/code/src.corelib.kernel.qmetatype.cpp 8
+    \snippet doc/src/snippets/code/src_corelib_kernel_qmetatype.cpp 8
 
     QMetaType::type() returns the same ID as qMetaTypeId(), but does
     a lookup at runtime based on the name of the type.
