@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
+**
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
 ** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
-**
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
-**
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
-**
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -47,6 +52,8 @@
 #include "q3sqlrecordinfo.h"
 #include "q3sqlfieldinfo.h"
 
+QT_BEGIN_NAMESPACE
+
 class Q3SqlCursorPrivate
 {
 public:
@@ -157,15 +164,7 @@ QString qWhereClause(QSqlRecord* rec, const QString& prefix, const QString& sep,
 
     For example:
 
-    \code
-    Q3SqlCursor cur( "staff" ); // Specify the table/view name
-    cur.select(); // We'll retrieve every record
-    while ( cur.next() ) {
-        qDebug( cur.value( "id" ).toString() + ": " +
-        cur.value( "surname" ).toString() + " " +
-        cur.value( "salary" ).toString() );
-    }
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 0
 
     In the above example, a cursor is created specifying a table or
     view name in the database. Then, select() is called, which can be
@@ -189,17 +188,7 @@ QString qWhereClause(QSqlRecord* rec, const QString& prefix, const QString& sep,
 
     For example:
 
-    \code
-    Q3SqlCursor cur( "prices" );
-    cur.select( "id=202" );
-    if ( cur.next() ) {
-        QSqlRecord *buffer = cur.primeUpdate();
-        double price = buffer->value( "price" ).toDouble();
-        double newprice = price * 1.05;
-        buffer->setValue( "price", newprice );
-        cur.update();
-    }
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 1
 
     To edit an existing database record, first move to the record you
     wish to update. Call primeUpdate() to get the pointer to the
@@ -634,33 +623,14 @@ QSqlIndex Q3SqlCursor::index(const QString& fieldName) const
     row, use seek(), first(), last(), previous() or next().
 
     Example:
-    \code
-    Q3SqlCursor cur("Employee"); // Use the Employee table or view
-    cur.select("deptno=10"); // select all records in department 10
-    while(cur.next()) {
-        ... // process data
-    }
-    ...
-    // select records in other departments, ordered by department number
-    cur.select("deptno>10", cur.index("deptno"));
-    ...
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 2
 
     The filter will apply to any subsequent select() calls that do not
     explicitly specify another filter. Similarly the sort will apply
     to any subsequent select() calls that do not explicitly specify
     another sort.
 
-    \code
-    Q3SqlCursor cur("Employee");
-    cur.select("deptno=10"); // select all records in department 10
-    while(cur.next()) {
-        ... // process data
-    }
-    ...
-    cur.select(); // re-selects all records in department 10
-    ...
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 3
 
 */
 
@@ -675,7 +645,7 @@ bool Q3SqlCursor::select(const QString & filter, const QSqlIndex & sort)
         d->ftr = filter;
         str += QLatin1String(" where ") + filter;
     } else
-        d->ftr = QString();
+        d->ftr.clear();
     if (sort.count() > 0)
         str += QLatin1String(" order by ") + sort.toString(d->nm);
     d->srt = sort;
@@ -734,13 +704,7 @@ bool Q3SqlCursor::select(const QSqlIndex& sort)
     last(), previous() or next(). This function is useful, for example,
     for retrieving data based upon a table's primary index:
 
-    \code
-    Q3SqlCursor cur("Employee");
-    QSqlIndex pk = cur.primaryIndex();
-    cur.setValue("id", 10);
-    cur.select(pk, pk); // generates "SELECT ... FROM Employee WHERE id=10 ORDER BY id"
-    ...
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 4
 
     In this example the QSqlIndex, pk, is used for two different
     purposes. When used as the filter (first) argument, the field
@@ -760,15 +724,7 @@ bool Q3SqlCursor::select(const QSqlIndex & filter, const QSqlIndex & sort)
     combination of \l Q3SqlCursor::Mode values. The default mode for a
     cursor is Q3SqlCursor::Writable.
 
-    \code
-    Q3SqlCursor cur("Employee");
-    cur.setMode(Q3SqlCursor::Writable); // allow insert/update/delete
-    ...
-    cur.setMode(Q3SqlCursor::Insert | Q3SqlCursor::Update); // allow inserts and updates only
-    ...
-    cur.setMode(Q3SqlCursor::ReadOnly); // no inserts/updates/deletes allowed
-
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 5
 */
 
 void Q3SqlCursor::setMode(int mode)
@@ -1006,14 +962,7 @@ QString Q3SqlCursor::toString(const QSqlIndex& i, QSqlRecord* rec, const QString
     new select() call must be made before navigating to a valid
     record.
 
-    \code
-    Q3SqlCursor cur("prices");
-    QSqlRecord *buffer = cur.primeInsert();
-    buffer->setValue("id",    53981);
-    buffer->setValue("name",  "Thingy");
-    buffer->setValue("price", 105.75);
-    cur.insert();
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 6
 
     In the above example, a cursor is created on the 'prices' table
     and a pointer to the insert buffer is acquired using primeInsert().
@@ -1181,17 +1130,7 @@ QSqlRecord* Q3SqlCursor::primeInsert()
     longer be navigated. A new select() call must be made before you
     can move to a valid record. For example:
 
-    \code
-    Q3SqlCursor cur("prices");
-    cur.select("id=202");
-    if (cur.next()) {
-        QSqlRecord *buffer = cur.primeUpdate();
-        double price = buffer->value("price").toDouble();
-        double newprice = price * 1.05;
-        buffer->setValue("price", newprice);
-        cur.update();
-    }
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 7
 
     In the above example, a cursor is created on the 'prices' table
     and is positioned on the record to be updated. Then a pointer to
@@ -1293,14 +1232,7 @@ int Q3SqlCursor::update(const QString & filter, bool invalidate)
     be navigated. A new select() call must be made before you can move
     to a valid record. For example:
 
-    \code
-    Q3SqlCursor cur("prices");
-    cur.select("id=999");
-    if (cur.next()) {
-        cur.primeDelete();
-        cur.del();
-    }
-    \endcode
+    \snippet doc/src/snippets/code/src_qt3support_sql_q3sqlcursor.cpp 8
 
     In the above example, a cursor is created on the 'prices' table
     and positioned to the record to be deleted. First primeDelete() is
@@ -1582,4 +1514,6 @@ bool Q3SqlCursor::last()
     return res;
 }
 
+QT_END_NAMESPACE
+
 #endif
