@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the QtSql module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -121,9 +119,9 @@ void QPSQLDriverPrivate::appendTables(QStringList &tl, QSqlQuery &t, QChar type)
                   "and (pg_class.relname !~ '^pg_') "
                   "and (pg_namespace.nspname != 'information_schema') ").arg(type);
     } else {
-        query = QString::fromLatin1("select relname, null from pg_class where (relkind = 'r') "
+        query = QString::fromLatin1("select relname, null from pg_class where (relkind = '%1') "
                   "and (relname !~ '^Inv') "
-                  "and (relname !~ '^pg_') ");
+                  "and (relname !~ '^pg_') ").arg(type);
     }
     t.exec(query);
     while (t.next()) {
@@ -237,7 +235,7 @@ static void qDeallocatePreparedStmt(QPSQLResultPrivate *d)
     if (PQresultStatus(result) != PGRES_COMMAND_OK)
         qWarning("Unable to free statement: %s", PQerrorMessage(d->driver->connection));
     PQclear(result);
-    d->preparedStmtId = QString();
+    d->preparedStmtId.clear();
 }
 
 QPSQLResult::QPSQLResult(const QPSQLDriver* db, const QPSQLDriverPrivate* p)
@@ -471,7 +469,7 @@ void QPSQLResult::virtual_hook(int id, void *data)
         d->precisionPolicy = *reinterpret_cast<QSql::NumericalPrecisionPolicy *>(data);
         break;
     default:
-        Q_ASSERT(false);
+        QSqlResult::virtual_hook(id, data);
     }
 }
 
@@ -552,7 +550,7 @@ bool QPSQLResult::prepare(const QString &query)
         setLastError(qMakeError(QCoreApplication::translate("QPSQLResult",
                                 "Unable to prepare statement"), QSqlError::StatementError, d->driver));
         PQclear(result);
-        d->preparedStmtId = QString();
+        d->preparedStmtId.clear();
         return false;
     }
 
@@ -650,7 +648,7 @@ static QPSQLDriver::Protocol getPSQLVersion(PGconn* connection)
         }
     }
 
-    if (serverVersion < QPSQLDriver::Version73)
+    if (serverVersion < QPSQLDriver::Version71)
         qWarning("This version of PostgreSQL is not supported and may not work.");
 
     return serverVersion;
@@ -1089,11 +1087,11 @@ QString QPSQLDriver::formatValue(const QSqlField &field, bool trimStrings) const
                           + tm.toString() + QLatin1String(".")
                           + QString::number(tm.msec()).rightJustified(3, QLatin1Char('0'))
                           + QLatin1String("'");
-            } else
-#else
-            {
+            } else {
                 r = QLatin1String("NULL");
             }
+#else
+            r = QLatin1String("NULL");
 #endif // QT_NO_DATESTRING
             break;
         case QVariant::Time:
