@@ -1,48 +1,49 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Contact: Qt Software Information (qt-info@nokia.com)
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain
+** additional rights. These rights are described in the Nokia Qt LGPL
+** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
+** package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "abstractformeditor.h"
-#include "private/qobject_p.h"
+#include "abstractdialoggui_p.h"
+#include "abstractintrospection_p.h"
+#include "abstractsettings_p.h"
+#include "abstractoptionspage_p.h"
 
 #include <QtDesigner/QDesignerWidgetBoxInterface>
 #include <QtDesigner/QDesignerPropertyEditorInterface>
@@ -57,11 +58,26 @@
 #include <QtDesigner/QDesignerIconCacheInterface>
 #include <QtDesigner/QDesignerActionEditorInterface>
 #include <pluginmanager_p.h>
+#include <qtresourcemodel_p.h>
+#include <qtgradientmanager.h>
+#include <widgetfactory_p.h>
+#include <shared_settings_p.h>
+#include <formwindowbase_p.h>
+#include <grid_p.h>
 #include <QtDesigner/QDesignerPromotionInterface>
 
-class QDesignerFormEditorInterfacePrivate : public  QObjectPrivate {
+static void initResources()
+{
+    Q_INIT_RESOURCE(shared);
+}
+
+QT_BEGIN_NAMESPACE
+
+class QDesignerFormEditorInterfacePrivate {
 public:
-    QDesignerFormEditorInterfacePrivate() : m_pluginManager(0),m_promotion(0) {}
+    QDesignerFormEditorInterfacePrivate();
+    ~QDesignerFormEditorInterfacePrivate();
+
 
     QPointer<QWidget> m_topLevel;
     QPointer<QDesignerWidgetBoxInterface> m_widgetBox;
@@ -76,10 +92,38 @@ public:
     QPointer<QDesignerIntegrationInterface> m_integration;
     QPointer<QDesignerIconCacheInterface> m_iconCache;
     QPointer<QDesignerActionEditorInterface> m_actionEditor;
+    QDesignerSettingsInterface *m_settingsManager;
     QDesignerPluginManager *m_pluginManager;
     QDesignerPromotionInterface *m_promotion;
+    QDesignerIntrospectionInterface *m_introspection;
+    QDesignerDialogGuiInterface *m_dialogGui;
+    QPointer<QtResourceModel> m_resourceModel;
+    QPointer<QtGradientManager> m_gradientManager; // instantiated and deleted by designer_integration
+    QList<QDesignerOptionsPageInterface*> m_optionsPages;
 };
 
+QDesignerFormEditorInterfacePrivate::QDesignerFormEditorInterfacePrivate() :
+    m_settingsManager(0),
+    m_pluginManager(0),
+    m_promotion(0),
+    m_introspection(0),
+    m_dialogGui(0),
+    m_resourceModel(0),
+    m_gradientManager(0)
+{
+}
+
+QDesignerFormEditorInterfacePrivate::~QDesignerFormEditorInterfacePrivate()
+{
+    delete m_settingsManager;
+    delete m_formWindowManager;
+    delete m_promotion;
+    delete m_introspection;
+    delete m_dialogGui;
+    delete m_resourceModel;
+    qDeleteAll(m_optionsPages);
+}
+
 /*!
     \class QDesignerFormEditorInterface
 
@@ -96,15 +140,7 @@ public:
     these components. They are typically used to query (and
     manipulate) the respective component. For example:
 
-    \code
-        QDesignerObjectInspectorInterface *objectInspector = 0;
-        objectInspector = formEditor->objectInspector();
-
-        QDesignerFormWindowManagerInterface *manager = 0;
-        manager = formEditor->formWindowManager();
-
-        objectInspector->setFormWindow(manager->formWindow(0));
-    \endcode
+    \snippet doc/src/snippets/code/tools_designer_src_lib_sdk_abstractformeditor.cpp 0
 
     QDesignerFormEditorInterface is not intended to be instantiated
     directly. A pointer to \QD's current QDesignerFormEditorInterface
@@ -119,6 +155,11 @@ public:
     box. These are only useful if you want to provide your own custom
     components.
 
+    If designer is embedded in another program, one could to provide its
+    own settings manager. The manager is used by the components of \QD
+    to store/retrieve persistent configuration settings. The default
+    manager uses QSettings as the backend.
+
     Finally, QDesignerFormEditorInterface provides the topLevel()
     function that returns \QD's top-level widget.
 
@@ -131,9 +172,10 @@ public:
 */
 
 QDesignerFormEditorInterface::QDesignerFormEditorInterface(QObject *parent)
-    : QObject(*(new QDesignerFormEditorInterfacePrivate), parent),
-      m_pad13(0)
+    : QObject(parent),
+      d(new QDesignerFormEditorInterfacePrivate())
 {
+    initResources();
 }
 
 /*!
@@ -141,6 +183,7 @@ QDesignerFormEditorInterface::QDesignerFormEditorInterface(QObject *parent)
 */
 QDesignerFormEditorInterface::~QDesignerFormEditorInterface()
 {
+    delete d;
 }
 
 /*!
@@ -149,9 +192,8 @@ QDesignerFormEditorInterface::~QDesignerFormEditorInterface()
     \sa setWidgetBox()
 */
 QDesignerWidgetBoxInterface *QDesignerFormEditorInterface::widgetBox() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_widgetBox; 
+{
+    return d->m_widgetBox;
 }
 
 /*!
@@ -160,9 +202,8 @@ QDesignerWidgetBoxInterface *QDesignerFormEditorInterface::widgetBox() const
     \sa widgetBox()
 */
 void QDesignerFormEditorInterface::setWidgetBox(QDesignerWidgetBoxInterface *widgetBox)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_widgetBox = widgetBox; 
+{
+    d->m_widgetBox = widgetBox;
 }
 
 /*!
@@ -171,9 +212,8 @@ void QDesignerFormEditorInterface::setWidgetBox(QDesignerWidgetBoxInterface *wid
     \sa setPropertyEditor()
 */
 QDesignerPropertyEditorInterface *QDesignerFormEditorInterface::propertyEditor() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_propertyEditor; 
+{
+    return d->m_propertyEditor;
 }
 
 /*!
@@ -182,9 +222,8 @@ QDesignerPropertyEditorInterface *QDesignerFormEditorInterface::propertyEditor()
     \sa propertyEditor()
 */
 void QDesignerFormEditorInterface::setPropertyEditor(QDesignerPropertyEditorInterface *propertyEditor)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_propertyEditor = propertyEditor; 
+{
+    d->m_propertyEditor = propertyEditor;
 }
 
 /*!
@@ -193,9 +232,8 @@ void QDesignerFormEditorInterface::setPropertyEditor(QDesignerPropertyEditorInte
     \sa setActionEditor()
 */
 QDesignerActionEditorInterface *QDesignerFormEditorInterface::actionEditor() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_actionEditor; 
+{
+    return d->m_actionEditor;
 }
 
 /*!
@@ -204,27 +242,24 @@ QDesignerActionEditorInterface *QDesignerFormEditorInterface::actionEditor() con
     \sa actionEditor()
 */
 void QDesignerFormEditorInterface::setActionEditor(QDesignerActionEditorInterface *actionEditor)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_actionEditor = actionEditor; 
+{
+    d->m_actionEditor = actionEditor;
 }
 
 /*!
     Returns \QD's top-level widget.
 */
 QWidget *QDesignerFormEditorInterface::topLevel() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_topLevel; 
+{
+    return d->m_topLevel;
 }
 
 /*!
     \internal
 */
 void QDesignerFormEditorInterface::setTopLevel(QWidget *topLevel)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_topLevel = topLevel; 
+{
+    d->m_topLevel = topLevel;
 }
 
 /*!
@@ -232,35 +267,31 @@ void QDesignerFormEditorInterface::setTopLevel(QWidget *topLevel)
 */
 QDesignerFormWindowManagerInterface *QDesignerFormEditorInterface::formWindowManager() const
 {
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_formWindowManager; 
+    return d->m_formWindowManager;
 }
 
 /*!
     \internal
 */
 void QDesignerFormEditorInterface::setFormManager(QDesignerFormWindowManagerInterface *formWindowManager)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_formWindowManager = formWindowManager; 
+{
+    d->m_formWindowManager = formWindowManager;
 }
 
 /*!
     Returns an interface to \QD's extension manager.
 */
 QExtensionManager *QDesignerFormEditorInterface::extensionManager() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_extensionManager; 
+{
+    return d->m_extensionManager;
 }
 
 /*!
     \internal
 */
 void QDesignerFormEditorInterface::setExtensionManager(QExtensionManager *extensionManager)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_extensionManager = extensionManager; 
+{
+    d->m_extensionManager = extensionManager;
 }
 
 /*!
@@ -269,18 +300,16 @@ void QDesignerFormEditorInterface::setExtensionManager(QExtensionManager *extens
     Returns an interface to the meta database used by the form editor.
 */
 QDesignerMetaDataBaseInterface *QDesignerFormEditorInterface::metaDataBase() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_metaDataBase; 
+{
+    return d->m_metaDataBase;
 }
 
 /*!
     \internal
 */
 void QDesignerFormEditorInterface::setMetaDataBase(QDesignerMetaDataBaseInterface *metaDataBase)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_metaDataBase = metaDataBase; 
+{
+    d->m_metaDataBase = metaDataBase;
 }
 
 /*!
@@ -290,7 +319,6 @@ void QDesignerFormEditorInterface::setMetaDataBase(QDesignerMetaDataBaseInterfac
 */
 QDesignerWidgetDataBaseInterface *QDesignerFormEditorInterface::widgetDataBase() const
 {
-    Q_D(const QDesignerFormEditorInterface);
     return d->m_widgetDataBase;
 }
 
@@ -299,8 +327,7 @@ QDesignerWidgetDataBaseInterface *QDesignerFormEditorInterface::widgetDataBase()
 */
 void QDesignerFormEditorInterface::setWidgetDataBase(QDesignerWidgetDataBaseInterface *widgetDataBase)
 {
-    Q_D(QDesignerFormEditorInterface);
-    d->m_widgetDataBase = widgetDataBase; 
+    d->m_widgetDataBase = widgetDataBase;
 }
 
 /*!
@@ -311,7 +338,6 @@ void QDesignerFormEditorInterface::setWidgetDataBase(QDesignerWidgetDataBaseInte
 
 QDesignerPromotionInterface *QDesignerFormEditorInterface::promotion() const
 {
-    Q_D(const QDesignerFormEditorInterface);
     return d->m_promotion;
 }
 
@@ -323,7 +349,8 @@ QDesignerPromotionInterface *QDesignerFormEditorInterface::promotion() const
 
 void QDesignerFormEditorInterface::setPromotion(QDesignerPromotionInterface *promotion)
 {
-    Q_D(QDesignerFormEditorInterface);
+    if (d->m_promotion)
+        delete d->m_promotion;
     d->m_promotion = promotion;
 }
 
@@ -334,8 +361,7 @@ void QDesignerFormEditorInterface::setPromotion(QDesignerPromotionInterface *pro
     to create widgets for the form.
 */
 QDesignerWidgetFactoryInterface *QDesignerFormEditorInterface::widgetFactory() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
+{
     return d->m_widgetFactory;
 }
 
@@ -344,8 +370,7 @@ QDesignerWidgetFactoryInterface *QDesignerFormEditorInterface::widgetFactory() c
 */
 void QDesignerFormEditorInterface::setWidgetFactory(QDesignerWidgetFactoryInterface *widgetFactory)
 {
-    Q_D(QDesignerFormEditorInterface);
-    d->m_widgetFactory = widgetFactory; 
+    d->m_widgetFactory = widgetFactory;
 }
 
 /*!
@@ -353,8 +378,7 @@ void QDesignerFormEditorInterface::setWidgetFactory(QDesignerWidgetFactoryInterf
 */
 QDesignerObjectInspectorInterface *QDesignerFormEditorInterface::objectInspector() const
 {
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_objectInspector; 
+    return d->m_objectInspector;
 }
 
 /*!
@@ -364,8 +388,7 @@ QDesignerObjectInspectorInterface *QDesignerFormEditorInterface::objectInspector
     \sa objectInspector()
 */
 void QDesignerFormEditorInterface::setObjectInspector(QDesignerObjectInspectorInterface *objectInspector)
-{ 
-    Q_D(QDesignerFormEditorInterface);
+{
     d->m_objectInspector = objectInspector;
 }
 
@@ -375,9 +398,8 @@ void QDesignerFormEditorInterface::setObjectInspector(QDesignerObjectInspectorIn
     Returns an interface to the brush manager used by the palette editor.
 */
 QDesignerBrushManagerInterface *QDesignerFormEditorInterface::brushManager() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_brushManager; 
+{
+    return d->m_brushManager;
 }
 
 /*!
@@ -385,8 +407,7 @@ QDesignerBrushManagerInterface *QDesignerFormEditorInterface::brushManager() con
 */
 void QDesignerFormEditorInterface::setBrushManager(QDesignerBrushManagerInterface *brushManager)
 {
-    Q_D(QDesignerFormEditorInterface);
-    d->m_brushManager = brushManager; 
+    d->m_brushManager = brushManager;
 }
 
 /*!
@@ -395,18 +416,16 @@ void QDesignerFormEditorInterface::setBrushManager(QDesignerBrushManagerInterfac
     Returns an interface to the integration.
 */
 QDesignerIntegrationInterface *QDesignerFormEditorInterface::integration() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_integration; 
+{
+    return d->m_integration;
 }
 
 /*!
     \internal
 */
 void QDesignerFormEditorInterface::setIntegration(QDesignerIntegrationInterface *integration)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_integration = integration; 
+{
+    d->m_integration = integration;
 }
 
 /*!
@@ -416,29 +435,47 @@ void QDesignerFormEditorInterface::setIntegration(QDesignerIntegrationInterface
     manage icons.
 */
 QDesignerIconCacheInterface *QDesignerFormEditorInterface::iconCache() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_iconCache; 
+{
+    return d->m_iconCache;
 }
 
 /*!
     \internal
 */
 void QDesignerFormEditorInterface::setIconCache(QDesignerIconCacheInterface *cache)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_iconCache = cache; 
+{
+    d->m_iconCache = cache;
 }
 
+/*!
+    \internal
+    \since 4.5
+    Returns the list of options pages that allow the user to configure \QD components.
+*/
+QList<QDesignerOptionsPageInterface*> QDesignerFormEditorInterface::optionsPages() const
+{
+    return d->m_optionsPages;
+}
+
+/*!
+    \internal
+    \since 4.5
+    Sets the list of options pages that allow the user to configure \QD components.
+*/
+void QDesignerFormEditorInterface::setOptionsPages(const QList<QDesignerOptionsPageInterface*> &optionsPages)
+{
+    d->m_optionsPages = optionsPages;
+}
+
+
 /*!
     \internal
 
     Returns the plugin manager used by the form editor.
 */
 QDesignerPluginManager *QDesignerFormEditorInterface::pluginManager() const
-{ 
-    Q_D(const QDesignerFormEditorInterface);
-    return d->m_pluginManager; 
+{
+    return d->m_pluginManager;
 }
 
 /*!
@@ -448,9 +485,100 @@ QDesignerPluginManager *QDesignerFormEditorInterface::pluginManager() const
     \a pluginManager.
 */
 void QDesignerFormEditorInterface::setPluginManager(QDesignerPluginManager *pluginManager)
-{ 
-    Q_D(QDesignerFormEditorInterface);
-    d->m_pluginManager = pluginManager; 
+{
+    d->m_pluginManager = pluginManager;
+}
+
+/*!
+    \internal
+    \since 4.4
+    Returns the resource model used by the form editor.
+*/
+QtResourceModel *QDesignerFormEditorInterface::resourceModel() const
+{
+    return d->m_resourceModel;
+}
+
+/*!
+    \internal
+
+    Sets the resource model used by the form editor to the specified
+    \a resourceModel.
+*/
+void QDesignerFormEditorInterface::setResourceModel(QtResourceModel *resourceModel)
+{
+    d->m_resourceModel = resourceModel;
+}
+
+/*!
+    \internal
+    \since 4.4
+    Returns the gradient manager used by the style sheet editor.
+*/
+QtGradientManager *QDesignerFormEditorInterface::gradientManager() const
+{
+    return d->m_gradientManager;
+}
+
+/*!
+    \internal
+
+    Sets the gradient manager used by the style sheet editor to the specified
+    \a gradientManager.
+*/
+void QDesignerFormEditorInterface::setGradientManager(QtGradientManager *gradientManager)
+{
+    d->m_gradientManager = gradientManager;
+}
+
+/*!
+    \internal
+    \since 4.5
+    Returns the settings manager used by the components to store persistent settings.
+*/
+QDesignerSettingsInterface *QDesignerFormEditorInterface::settingsManager() const
+{
+    return d->m_settingsManager;
+}
+
+/*!
+    \internal
+    \since 4.5
+    Sets the settings manager used to store/retrieve the persistent settings of the components.
+*/
+void QDesignerFormEditorInterface::setSettingsManager(QDesignerSettingsInterface *settingsManager)
+{
+    if (d->m_settingsManager)
+        delete d->m_settingsManager;
+    d->m_settingsManager = settingsManager;
+
+    // This is a (hopefully) safe place to perform settings-dependent
+    // initializations.
+    const qdesigner_internal::QDesignerSharedSettings settings(this);
+    qdesigner_internal::FormWindowBase::setDefaultDesignerGrid(settings.defaultGrid());
+}
+
+/*!
+    \internal
+    \since 4.4
+    Returns the introspection used by the form editor.
+*/
+QDesignerIntrospectionInterface *QDesignerFormEditorInterface::introspection() const
+{
+    return d->m_introspection;
+}
+
+/*!
+    \internal
+    \since 4.4
+
+    Sets the introspection used by the form editor to the specified \a introspection.
+*/
+void QDesignerFormEditorInterface::setIntrospection(QDesignerIntrospectionInterface *introspection)
+{
+    if (d->m_introspection)
+        delete d->m_introspection;
+     d->m_introspection = introspection;
 }
 
 /*!
@@ -466,3 +594,28 @@ QString QDesignerFormEditorInterface::resourceLocation() const
     return QLatin1String(":/trolltech/formeditor/images/win");
 #endif
 }
+
+/*!
+    \internal
+
+    Returns the dialog GUI used by the form editor.
+*/
+
+QDesignerDialogGuiInterface *QDesignerFormEditorInterface::dialogGui() const
+{
+    return d->m_dialogGui;
+}
+
+/*!
+    \internal
+
+    Sets the dialog GUI used by the form editor to the specified \a dialogGui.
+*/
+
+void QDesignerFormEditorInterface::setDialogGui(QDesignerDialogGuiInterface *dialogGui)
+{
+    delete  d->m_dialogGui;
+    d->m_dialogGui = dialogGui;
+}
+
+QT_END_NAMESPACE
